@@ -27,7 +27,7 @@
 /* #undef ENABLE_WOLFSSL */
 
 // enable integration with boost for networking.
-#define ENABLE_BOOST ON
+/* #undef ENABLE_BOOST */
 
 // enable the use of intel SSE instructions.
 #define ENABLE_SSE ON
